@@ -10,12 +10,12 @@ Network::Network()
 {
 }
 
-const std::vector<PAgent> &Network::contact(double time, Agent &agent)
+const std::vector<Agent*> &Network::contact(double time, Agent &agent)
 {
-  return _neighbors[agent.id() - 1];
+  return _neighbors[agent.index()];
 }
 
-void Network::add(const PAgent &agent)
+void Network::add(Agent &agent)
 {
   // have we finalized?
   if (_population != nullptr) grow(agent);
@@ -26,10 +26,10 @@ void Network::remove(Agent &agent)
   size_t i = agent.id() - 1;
   for (auto c : _neighbors[i]) {
     size_t j = c->id() - 1;
-    std::vector<PAgent> &nj = _neighbors[j];
+    std::vector<Agent*> &nj = _neighbors[j];
     size_t m = nj.size();
     for (size_t k = 0; k < m - 1; ++k) {
-      if (nj[k].get() == &agent) {
+      if (nj[k] == &agent) {
         nj[k] = nj[m-1];
         break;
       }
@@ -56,13 +56,13 @@ void ConfigurationModel::buildNetwork()
   IntegerVector d = _rng(_neighbors.size());
   size_t L = sum(d) + 0.5;
   std::vector<int> stubs(L);
-  for (size_t i = 1, k = 0; i <= d.size(); ++i)
+  for (size_t i = 0, k = 0; i < d.size(); ++i)
     for (size_t j = 0; j < d[i]; ++j)
       stubs[k++] = i;
   size_t from, to, n = stubs.size();
   while (n > 2) {
-    from = RUnif::stdUnif.get() * n;
-    to = RUnif::stdUnif.get() * n;
+    from = _unif.get() * n;
+    to = _unif.get() * n;
     connect(stubs[from], stubs[to]);
     stubs[from] = stubs[n-1];
     stubs[to] = stubs[n-2];
@@ -74,33 +74,31 @@ void Network::connect(int from, int to)
 {
   if (from == to) return;
   // avoid multiple loops
-  auto t = _population->agentByID(to);
-  for (auto c : _neighbors[from - 1])
+  auto t = _population->agentAtIndex(to).get();
+  for (auto c : _neighbors[from])
     if (c == t) return;
-  _neighbors[from - 1].push_back(t);
-  _neighbors[to - 1].push_back(_population->agentByID(from));
+  _neighbors[from].push_back(t);
+  _neighbors[to].push_back(_population->agentAtIndex(from).get());
 }
 
-void ConfigurationModel::grow(const PAgent &agent)
+void ConfigurationModel::grow(Agent &agent)
 {
-  size_t i = agent->id() - 1;
+  Agent::IndexType i = agent.index();
   int degree = as<int>(_rng(1));
   std::vector<size_t> neighborhood(degree);
   size_t L = 0;
   for (auto c : _neighbors)
     L += c.size();
-  for (int i = 0; i < degree; ++i)
-    neighborhood[i] = L * RUnif::stdUnif.get();
+  for (int j = 0; j < degree; ++j)
+    neighborhood[j] = L * _unif.get();
   std::sort(neighborhood.begin(), neighborhood.end());
-  size_t k = 0;
+  size_t k = 0, total = 0;
   for (auto c : _neighbors) {
-    size_t d = c.size();
-    while (neighborhood[k] < d) {
-      connect(i, ++k);
+    total += c.size();
+    if (neighborhood[k] < total) {
+      connect(i, k++);
       if (k == degree) return;
     }
-    for (size_t i = k; i < degree; ++i)
-      neighborhood[i] -= d;
   }
 }
 
